@@ -1,41 +1,41 @@
 import pandas as pd
-from pandas_ta.utils import get_offset, non_zero_range, verify_series
+# from pandas_ta.utils import get_offset, non_zero_range, verify_series
 import numpy as np
 import pandas_ta as ta
 
 
-def stochastic_oscillator(dataframe, k=14, d=3, smooth_k=3, mamode='sma'):
-    """ Function to calculate stochastic oscillator """
-    try:
-        # Calculate the rolling lowest low and highest high over the K period
-        k = k if k and k > 0 else 14
-        d = d if d and d > 0 else 3
-
-        smooth_k = smooth_k if smooth_k and smooth_k > 0 else 3
-        _length = max(k, d, smooth_k)
-
-        high = verify_series(dataframe["high"], _length)
-        low = verify_series(dataframe["low"], _length)
-        close = verify_series(dataframe["close"], _length)
-
-        if high is None or low is None or close is None: return
-
-        # Calculate Result
-        lowest_low = low.rolling(k).min()
-        highest_high = high.rolling(k).max()
-
-        stoch = 100 * (close - lowest_low)
-        stoch /= non_zero_range(highest_high, lowest_low)
-        stoch_k = stoch.rolling(smooth_k).mean()
-        stoch_d = stoch_k.rolling(d).mean()
-
-        new_df = pd.DataFrame()
-        new_df["k"] = stoch_k
-        new_df["d"] = stoch_d
-        return new_df
-    except Exception as e:
-        print("Exception in calculating stochastic oscillator : {}".format(e))
-        return None
+# def stochastic_oscillator(dataframe, k=14, d=3, smooth_k=3, mamode='sma'):
+#     """ Function to calculate stochastic oscillator """
+#     try:
+#         # Calculate the rolling lowest low and highest high over the K period
+#         k = k if k and k > 0 else 14
+#         d = d if d and d > 0 else 3
+#
+#         smooth_k = smooth_k if smooth_k and smooth_k > 0 else 3
+#         _length = max(k, d, smooth_k)
+#
+#         high = verify_series(dataframe["high"], _length)
+#         low = verify_series(dataframe["low"], _length)
+#         close = verify_series(dataframe["close"], _length)
+#
+#         if high is None or low is None or close is None: return
+#
+#         # Calculate Result
+#         lowest_low = low.rolling(k).min()
+#         highest_high = high.rolling(k).max()
+#
+#         stoch = 100 * (close - lowest_low)
+#         stoch /= non_zero_range(highest_high, lowest_low)
+#         stoch_k = stoch.rolling(smooth_k).mean()
+#         stoch_d = stoch_k.rolling(d).mean()
+#
+#         new_df = pd.DataFrame()
+#         new_df["k"] = stoch_k
+#         new_df["d"] = stoch_d
+#         return new_df
+#     except Exception as e:
+#         print("Exception in calculating stochastic oscillator : {}".format(e))
+#         return None
 
 
 def volume_flow_indicator(dataframe, length, coef, vcoef, signal_length, smooth_vfi=False):
@@ -101,42 +101,42 @@ def williams_fractal(dataframe, fractal_window=2):
         pass
 
 
-def mcgd(close, length=None, offset=None, c=None, **kwargs):
-    """ Indicator: McGinley Dynamic Indicator """
-    # Validate arguments
-    length = int(length) if length and length > 0 else 10
-    c = float(c) if c and 0 < c <= 1 else 1
-    close = verify_series(close, length)
-    offset = get_offset(offset)
-
-    if close is None: return
-
-    # Calculate Result
-    close = close.copy()
-
-    def mcg_(series):
-        denom = (c * length * (series.iloc[1] / series.iloc[0]) ** 4)
-        series.iloc[1] = (series.iloc[0] + ((series.iloc[1] - series.iloc[0]) / denom))
-        return series.iloc[1]
-
-    mcg_cell = close[0:].rolling(2, min_periods=2).apply(mcg_, raw=False)
-    mcg_ds = close[:1]._append(mcg_cell[1:])
-
-    # Offset
-    if offset != 0:
-        mcg_ds = mcg_ds.shift(offset)
-
-    # Handle fills
-    if "fillna" in kwargs:
-        mcg_ds.fillna(kwargs["fillna"], inplace=True)
-    if "fill_method" in kwargs:
-        mcg_ds.fillna(method=kwargs["fill_method"], inplace=True)
-
-    # Name & Category
-    mcg_ds.name = f"MCGD_{length}"
-    mcg_ds.category = "overlap"
-
-    return mcg_ds
+# def mcgd(close, length=None, offset=None, c=None, **kwargs):
+#     """ Indicator: McGinley Dynamic Indicator """
+#     # Validate arguments
+#     length = int(length) if length and length > 0 else 10
+#     c = float(c) if c and 0 < c <= 1 else 1
+#     close = verify_series(close, length)
+#     offset = get_offset(offset)
+#
+#     if close is None: return
+#
+#     # Calculate Result
+#     close = close.copy()
+#
+#     def mcg_(series):
+#         denom = (c * length * (series.iloc[1] / series.iloc[0]) ** 4)
+#         series.iloc[1] = (series.iloc[0] + ((series.iloc[1] - series.iloc[0]) / denom))
+#         return series.iloc[1]
+#
+#     mcg_cell = close[0:].rolling(2, min_periods=2).apply(mcg_, raw=False)
+#     mcg_ds = close[:1]._append(mcg_cell[1:])
+#
+#     # Offset
+#     if offset != 0:
+#         mcg_ds = mcg_ds.shift(offset)
+#
+#     # Handle fills
+#     if "fillna" in kwargs:
+#         mcg_ds.fillna(kwargs["fillna"], inplace=True)
+#     if "fill_method" in kwargs:
+#         mcg_ds.fillna(method=kwargs["fill_method"], inplace=True)
+#
+#     # Name & Category
+#     mcg_ds.name = f"MCGD_{length}"
+#     mcg_ds.category = "overlap"
+#
+#     return mcg_ds
 
 
 def squeeze_momentum(dataframe, bb_length=20, bb_mult=2.0, kc_length=20, kc_mult=1.5, use_true_range=True):
