@@ -13,7 +13,7 @@ def place_lt_order(tradingsymbol, quantity, transaction_type, order_type, lot_si
     try:
 
         if order_type == "MARKET":
-            order_data_params = {"tradingsymbol": tradingsymbol,
+            order_data_params = {"symbol": tradingsymbol,
                                  "exchange": exchange,
                                  "transaction_type": transaction_type,
                                  "quantity": quantity * lot_size,
@@ -23,25 +23,25 @@ def place_lt_order(tradingsymbol, quantity, transaction_type, order_type, lot_si
 
             order_response = place_live_order(credential_id=credential_id, order_details=order_data_params)
 
-            if order_response["status"] == "COMPLETE":
+            if order_response["status"] == "success":
                 return "success", order_response
             else:
-                return "failed", None
+                return "error", order_response
 
-        elif order_type == "SL":
-            order_data_params = {"tradingsymbol": tradingsymbol, "exchange": exchange,
+        elif order_type == "STOPLOSS":
+            order_data_params = {"symbol": tradingsymbol, "exchange": exchange,
                                  "transaction_type": transaction_type,
                                  "quantity": quantity * lot_size, "product": "MIS", "validity": "DAY",
-                                 "order_type": "SL", "trigger_price": trigger_price, "price": order_price}
+                                 "order_type": "STOPLOSS", "trigger_price": trigger_price, "price": order_price}
             order_response = place_live_order(credential_id=credential_id, order_details=order_data_params)
 
             if order_response["status"] == "success":
                 return "success", order_response["order_id"]
             else:
-                return "failed", None
+                return "error", order_response
 
         elif order_type == "LIMIT":
-            order_data_params = {"tradingsymbol": tradingsymbol, "exchange": exchange,
+            order_data_params = {"symbol": tradingsymbol, "exchange": exchange,
                                  "transaction_type": transaction_type, "quantity": quantity * lot_size,
                                  "product": "MIS", "validity": "TTL", "validity_ttl": 1,
                                  "order_type": "LIMIT",  "price": order_price}
@@ -51,7 +51,7 @@ def place_lt_order(tradingsymbol, quantity, transaction_type, order_type, lot_si
             if order_response["status"] == "success":
                 return "success", order_response["order_id"]
             else:
-                return "failed", None
+                return "error", order_response
 
     except Exception as e:
         print(f"Exception in placing live trade : {e}")
@@ -156,7 +156,7 @@ def place_live_order(credential_id, order_details):
     try:
         print("Placing Live Trade Order")
         request_dict = {"credential_id": str(credential_id),
-                        "order_params": json.dumps(order_details)}
+                        "order_params": order_details}
         print(f"request_dict : {request_dict}")
 
         response = requests.post(url=orders_url+"place_order", json=request_dict)
@@ -183,3 +183,31 @@ def modify_live_order(credential_id, order_details):
     except Exception as e:
         print(f"Exception in Modify Live Order : {e}")
         pass
+
+
+def check_order_status(credential_id, order_id, exchange):
+    """Function to fetch current order status"""
+    try:
+        print("Fetching Order Status")
+        request_dict = {
+            "credential_id": str(credential_id),
+            "order_params": {
+                'order_id': order_id,
+                "exchange": exchange
+            }
+        }
+        # last_order = requests.post(url=orders_url+"get_order_by_id", params={"credential_id": credential_id, 'order_details': json.dumps(get_order_params)}).json()
+        last_order = requests.post(url=orders_url+"check_order_status", json=request_dict).json()
+        print(f"order_status_response : {last_order}")
+
+        if last_order["status"] == "COMPLETED":
+            last_order["timestamp"] = datetime.datetime.strptime(str(last_order["timestamp"]), '%Y-%m-%d %H:%M:%S')
+            return "success", last_order
+
+        elif last_order["status"] == "CANCELLED" or last_order["status"] == "REJECTED":
+            return "cancelled", None
+        else:
+            return "error", None
+    except Exception as e:
+        print(f"Exception in Check Order Status Function : {e}")
+        return "failed", None
\ No newline at end of file
