@@ -209,21 +209,21 @@ def check_existing_order(symbol, exit_type, orders_list, entry_time):
         pass
 
 
-def check_order_status(credential_id, order_id, exchange):
-    """Function to fetch current order status"""
-    try:
-        print("Fetching Order Status")
-        get_order_params = {'order_id': order_id, "exchange": exchange}
-        last_order = requests.post(url=orders_url+"get_order_by_id", params={"credential_id": credential_id, 'order_details': json.dumps(get_order_params)}).json()
-        print(f"order_status_response : {last_order}")
-        if last_order["status"] == "COMPLETE":
-            last_order["exchange_timestamp"] = datetime.datetime.strptime(str(last_order["exchange_timestamp"]), '%Y-%m-%d %H:%M:%S')
-            return "success", last_order
-
-        elif last_order["status"] == "CANCELLED":
-            return "cancelled", None
-        else:
-            return "failed", None
-    except Exception as e:
-        print(f"Exception in Check Order Status Function : {e}")
-        return "failed", None
\ No newline at end of file
+# def check_order_status(credential_id, order_id, exchange):
+#     """Function to fetch current order status"""
+#     try:
+#         print("Fetching Order Status")
+#         get_order_params = {'order_id': order_id, "exchange": exchange}
+#         last_order = requests.post(url=orders_url+"get_order_by_id", params={"credential_id": credential_id, 'order_details': json.dumps(get_order_params)}).json()
+#         print(f"order_status_response : {last_order}")
+#         if last_order["status"] == "COMPLETE":
+#             last_order["exchange_timestamp"] = datetime.datetime.strptime(str(last_order["exchange_timestamp"]), '%Y-%m-%d %H:%M:%S')
+#             return "success", last_order
+#
+#         elif last_order["status"] == "CANCELLED":
+#             return "cancelled", None
+#         else:
+#             return "failed", None
+#     except Exception as e:
+#         print(f"Exception in Check Order Status Function : {e}")
+#         return "failed", None
\ No newline at end of file
